'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});
exports.bemjsonMethod = bemjsonMethod;

var _utils = require('./utils');

function bemjsonMethod(bemNaming, chai) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;

    return function (bemjson) {
        var _this = this;

        var entity = this._obj;

        // check input
        assert((0, _utils.isClassName)(entity) || (0, _utils.isDOMElement)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(bemjson, 'object');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // retrieve entities
        var entities = (0, _utils.getEntitiesFromBEMJSON)(bemjson);

        // check blocks
        entities.blocks.forEach(function (blockName) {
            _this.assert(className.indexOf(blockName) !== -1, 'expected #{this} to be #{exp} block but got #{act}', 'expected #{this} to not be #{exp} block but got #{act}', blockName, entity);
        });

        // check elems
        entities.elems.forEach(function (bemjsonEntity) {
            // check all elements
            _this.assert(className.some(function (item) {
                // ignore if not element
                if (!bemNaming.isElem(item)) {
                    return false;
                }

                var parsedItem = bemNaming.parse(item);

                return parsedItem.block === bemjsonEntity.block && parsedItem.elem === bemjsonEntity.elem;
            }), 'expected #{this} to be an elem #{exp} but got #{act}', 'expected #{this} to not be an elem of #{exp} block, but got #{act}', bemjsonEntity, entity);
        });

        // check mods
        entities.mods.forEach(function (bemjsonEntity) {
            var block = bemjsonEntity.block;
            var elem = bemjsonEntity.elem;
            var modName = bemjsonEntity.modName;

            var modVal = String(bemjsonEntity.modVal);

            _this.assert(className.some(function (item) {
                // ignore if no mods
                if (!bemNaming.isBlockMod(item) && !bemNaming.isElemMod(item)) {
                    return false;
                }

                var parsedItem = bemNaming.parse(item);

                return parsedItem.block === block && parsedItem.elem === elem && parsedItem.modName === modName && String(parsedItem.modVal) === modVal;
            }), 'expected #{this} to have #{exp} modificator', 'expected #{this} to not have #{exp} modificator', bemjsonEntity, entity);
        });
    };
}