'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});
exports.blockProperty = blockProperty;
exports.blockMethod = blockMethod;

var _utils = require('./utils');

function blockProperty(bemNaming, chai) {
    var assert = chai.assert;

    return function () {
        var entity = this._obj;

        // check input
        assert((0, _utils.isClassName)(entity) || (0, _utils.isDOMElement)(entity), entity + ' is neither a DOM element nor a className');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check block
        this.assert(className.some(function (item) {
            return bemNaming.isBlock(item);
        }), 'expected #{this} to be a block but got #{act}', 'expected #{this} to not be a block but got #{act}', entity, entity);
    };
}

function blockMethod(bemNaming, chai) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;

    return function (blockName) {
        var entity = this._obj;

        // check input
        assert((0, _utils.isClassName)(entity) || (0, _utils.isDOMElement)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(blockName, 'string');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check if there is at least one valid block
        assert(className.some(function (item) {
            return bemNaming.isBlock(item);
        }), 'there is no valid block in ' + entity);

        // check block
        this.assert(className.indexOf(blockName) !== -1, 'expected #{this} to be #{exp} block but got #{act}', 'expected #{this} to not be #{exp} block but got #{act}', blockName, entity);
    };
}