'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});
exports.modsMethod = modsMethod;

var _utils = require('./utils');

function modsMethod(bemNaming, chai) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;

    return function (bemjson) {
        var entity = this._obj;

        // check input
        assert((0, _utils.isClassName)(entity) || (0, _utils.isDOMElement)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(bemjson, 'object');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check mods
        var mods = Object.keys(bemjson);
        var modWord = 'modificator' + (mods.length === 1 ? '' : 's');

        this.assert(mods.every(function (modName) {
            // parsing to string to handle boolean and numeric mod values
            var modVal = String(bemjson[modName]);

            return className.some(function (item) {
                // ignore if no mods
                if (!bemNaming.isBlockMod(item) && !bemNaming.isElemMod(item)) {
                    return false;
                }

                var parsedItem = bemNaming.parse(item);

                return parsedItem.modName === modName && String(parsedItem.modVal) === modVal;
            });
        }), 'expected #{this} to have #{exp} ' + modWord, 'expected #{this} to not have #{exp} ' + modWord, bemjson, entity);
    };
}