'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.prepareClassName = prepareClassName;
exports.isClassName = isClassName;
exports.isDOMElement = isDOMElement;
exports.getEntitiesFromBEMJSON = getEntitiesFromBEMJSON;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _lodashIsplainobject = require('lodash.isplainobject');

var _lodashIsplainobject2 = _interopRequireDefault(_lodashIsplainobject);

function createEntitiesAggregator(entities) {
    return function (bemjson) {
        if ((0, _lodashIsplainobject2['default'])(bemjson)) {
            if ('block' in bemjson) {
                (function () {
                    if (typeof bemjson.block !== 'string') {
                        throw Error('block in ' + bemjson + ' should be a string');
                    }

                    var basicEntity = {
                        block: bemjson.block
                    };

                    if ('elem' in bemjson) {
                        if (typeof bemjson.elem !== 'string') {
                            throw Error('elem in ' + bemjson + ' should be a string');
                        }

                        basicEntity.elem = bemjson.elem;

                        entities.elems.push({
                            block: bemjson.block,
                            elem: bemjson.elem
                        });
                    } else {
                        entities.blocks.push(bemjson.block);
                    }

                    // mods
                    if ('mods' in bemjson) {
                        if (!(0, _lodashIsplainobject2['default'])(bemjson.mods)) {
                            throw Error('mods in ' + bemjson + ' should be a plain object');
                        }

                        Object.keys(bemjson.mods).forEach(function (modName) {
                            entities.mods.push(_extends({}, basicEntity, {
                                modName: modName,
                                modVal: bemjson.mods[modName]
                            }));
                        });
                    }
                })();
            } else {
                throw Error('there are no valid BEM entities in ' + bemjson);
            }
        } else {
            throw Error('expected ' + bemjson + ' to be a plain BEMJSON object');
        }
    };
}

function prepareClassName(element) {
    var className = isClassName(element) ? element : element.className;

    return className.trim().split(/\s+/);
}

function isClassName(element) {
    return typeof element === 'string';
}

function isDOMElement(element) {
    return typeof element === 'object' && element !== null && 'nodeType' in element && element.nodeType === 1;
}

function getEntitiesFromBEMJSON(bemjson) {
    var entities = {
        blocks: [],
        elems: [],
        mods: []
    };
    var fillEntitiesFrom = createEntitiesAggregator(entities);

    fillEntitiesFrom(bemjson);

    if ('mix' in bemjson) {
        if (Array.isArray(bemjson.mix)) {
            bemjson.mix.forEach(fillEntitiesFrom);
        } else {
            fillEntitiesFrom(bemjson.mix);
        }
    }

    return entities;
}